behavior

package
v0.20.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package behavior loads behavioral guidelines from ~/.config/piglet/behavior.md and injects them as the earliest system prompt section.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register(e *sdk.Extension)

Register schedules OnInit work via OnInitAppend to load and inject the behavior guidelines prompt section.

Types

This section is empty.

Directories

Path Synopsis
Behavior extension.
Behavior extension.

Jump to