gitcontext

package
v0.23.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package gitcontext injects uncommitted changes, recent commits, and small diffs into the system prompt so the model knows the repo state.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register(e *sdk.Extension)

Register schedules OnInit work via OnInitAppend to build and inject git context into the system prompt.

Types

This section is empty.

Directories

Path Synopsis
Git context extension.
Git context extension.

Jump to