subagent

package
v0.23.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package subagent provides the tmux-based agent dispatch tool for piglet. Agents are spawned as full piglet instances in tmux panes, giving the user full visibility and intervention capability.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register(e *sdk.Extension)

Register adds the dispatch tool to the extension.

Types

This section is empty.

Directories

Path Synopsis
Subagent extension binary.
Subagent extension binary.

Jump to